import pages
import unittest
import selenium.webdriver
class TextSearchTest(unittest.TestCase):
    def setUp(self):
        self.driver = selenium.webdriver.Firefox()
        self.page = pages.GoogleMain(self.driver, "http://www.google.com")

    def test_text_search(self):
        self.assertTrue(len(self.page.search("selenium").search_results) > 0)

    def test_text_search_first_result(self):
        self.page.search("selenium") # execute the page object method search
        self.assertEquals( self.page.search_results[0]["title"], "Selenium - Web Browser Automation")
        self.assertEquals( self.page.search_results[0]["link"], "http://seleniumhq.org/")

    def tearDown(self):
        self.driver.quit()



from selenium import webdriver

browser_mapping = {"firefox": webdriver.Firefox,
                    "chrome": webdriver.Chrome,
                    "ie": webdriver.Ie,
                    "opera" : webdriver.Opera,
                    "remote": webdriver.Remote,
                    "phantomjs": webdriver.PhantomJS,
                    "iphone" : webdriver.Remote,
                    "ipad": webdriver.Remote,
                    "android": webdriver.Remote}

#:
capabilities = {"firefox": webdriver.DesiredCapabilities.FIREFOX,
                "chrome": webdriver.DesiredCapabilities.CHROME,
                "ie": webdriver.DesiredCapabilities.INTERNETEXPLORER,
                "opera": webdriver.DesiredCapabilities.OPERA,
                "phantomjs":webdriver.DesiredCapabilities.PHANTOMJS,
                "iphone":webdriver.DesiredCapabilities.IPHONE,
                "ipad":webdriver.DesiredCapabilities.IPAD,
                "android":webdriver.DesiredCapabilities.ANDROID}




from holmium.core.logger import log
from holmium.core.testcase import HolmiumTestCase, browser_mapping, capabilities
from holmium.core.pageobject import Locators, PageObject, PageElement, PageElements
from holmium.core.pageobject import PageElementMap
from holmium.core.decorators import repeat
from holmium.core.noseplugin import HolmiumNose



from holmium.core import PageObject, PageElement, PageElements, Locators, PageElementMap


class GoogleMain(PageObject):
    search_box = PageElement( Locators.NAME, "q", timeout = 1)
    google_buttons = PageElementMap ( Locators.CLASS_NAME, "gbts" , timeout = 1 )
    search_results = PageElements( Locators.CSS_SELECTOR, "li.g", timeout = 1, value = lambda el : {
        "link":el.find_element_by_css_selector("h3.r>a").get_attribute("href"),
        "title":el.find_element_by_css_selector("h3.r>a").text
        })

    def search ( self, query ):
        self.google_buttons["Search"].click() # self.google_buttons behaves just like a dictionary
        self.search_box.clear() # self.search_box is now evaluated directly to a WebElement
        self.search_box.send_keys(query)
        self.search_box.submit()


